# define colors
WHITE = (255,255,255)
BLACK = (0,0,0)
RED = (255,0,0)
GREEN = (0,255,0)
BLUE = (0,0,255)
DARKGREY = (40,40,40)
LIGHTGREY = (100,100,100)
YELLOW = (255,255,0)

10
# game setting
TITLE = "BomberKillers"

WIDTH = 1024 # 16 * 64  or 32 * 32
HEIGHT = 768 # 16 * 48 or 32 * 24 or 64 * 12
FPS = 60
BGCOLOR= DARKGREY



TILESIZE = 33
GRIDWIDTH =  WIDTH / TILESIZE
GRIDHEIGHT = HEIGHT / TILESIZE

# image
WALL_IMAGE = 'wall.png'
BACKGROUND_IMAGE = 'background.png'
BOX_IMAGE = 'box.png'
PLAYER_IMAGE = 'player.png'
